@@ -41,7 +41,6 @@ withr::with_options(list(pillar.bold = TRUE), {
     expect_pillar_output(xf = colonnade(x, width = 39), filename = "multi-39.txt")
     expect_pillar_output(xf = colonnade(x, width = Inf), filename = "multi-inf.txt")
 
-    skip_on_os("windows")
     expect_pillar_output(
       xf = colonnade(
         rep(list(paste(letters, collapse = " ")), 4),
@@ -176,6 +175,15 @@ withr::with_options(list(pillar.bold = TRUE), {
     )
   })
 
+  test_that("sep argument", {
+    x <- list(sep = 1:3)
+    expect_pillar_output(
+      crayon = FALSE,
+      xf = colonnade(x, width = 30),
+      filename = "sep.txt"
+    )
+  })
+
   test_that("without styling", {
     xf <- colonnade(list(x = (10^(-3:4)) * c(-1, 1)))
 
